pub async fn setup(args: SessionSetupArgs<'_>) -> Result<SessionSetup>Expand description
Run the shared bootstrap. Returns once the container is up, the runtime user is bootstrapped, and the session directory + log dir exist.
pub async fn setup(args: SessionSetupArgs<'_>) -> Result<SessionSetup>Run the shared bootstrap. Returns once the container is up, the runtime user is bootstrapped, and the session directory + log dir exist.